@@ -1,5 +1,11 @@
 # -*- coding: utf-8 -*-
 
+###########################################################################
+## File:		functions_alarm.py
+## Description: This file includes the functions needed to set and modify
+##				the alarms
+###########################################################################
+
 from PyQt4 import QtCore, QtGui
 
 import sys
@@ -11,7 +17,6 @@ import math
 import array
 import string
 
-#import ConfigParser
 import os, os.path
 
 import data
@@ -26,14 +31,16 @@ try:
 except:
     pass
 
-
-#load language file
-import i18n
+import i18n #load language file
 _ = i18n.language.ugettext
 
 
+
 ###########################################################################
-## Sets the MAEMO alarm
+## Function:    SetAlarm
+## Description: This function adds the alarm to the MAEMO alarm queue
+## Parameters:  none
+## Returns:     none
 ###########################################################################
 def SetAlarm():
     if(data.DeviceIsN900==True): #We are on a N900
@@ -62,7 +69,7 @@ def SetAlarm():
         data.AlarmID = alarm.add_event(event)
 
         event = alarm.get_event(data.AlarmID) #read out again to check if set correctly
-        print "* Alarm will go off on:",  time.ctime(event.trigger)
+        print "* Alarm will go off on:", time.ctime(event.trigger)
     else:
         print "* Will not set alarm, Maemo interface not available"
         data.AlarmID=1
@@ -71,10 +78,18 @@ def SetAlarm():
 
 
 
+	
+	
+
+
 ###########################################################################
-## Delete all MAEMO alarms with appid "SleepAnalyser"
-## When SleepAnalyser crashed, it is possible that there is still an (old) alarm  in the dbus alarm queue
-## This function deletes them all
+## Function:    delete_all_preexisting_Alarms
+## Description: This function searchs for any SleepAnalyser alarms in the
+##				MAEMO alarm queue and deletes them
+##				In case SleepAnalyser crashed during recording, an alarm
+##				might still be in the queue
+## Parameters:  none
+## Returns:     none
 ###########################################################################
 def delete_all_preexisting_Alarms():
     print "* Search and delete all alarms from SleepAnalyser"
@@ -83,12 +98,10 @@ def delete_all_preexisting_Alarms():
         i=0
         for e in event:
             e2=alarm.get_event(e)
-#            print time.ctime(e2.trigger), e2.appid, e2.message #print all alarms
             if(e2.appid=="SleepAnalyser"): #filter our alarms
 #                print "Found one of our Alarms:", time.ctime(e2.trigger), e2.appid , e2.title, e2.message #print our alarms
                 alarm.delete_event(e)
                 i=i+1
-#                print "Deleted it"
         if(i==0): print "* No old alarms found"
         else: print "* Found", i, "of our alarms and deleted them"
     else:
@@ -99,7 +112,10 @@ def delete_all_preexisting_Alarms():
 
 
 ###########################################################################
-## Deletes the set MAEMO alarm
+## Function:    DeleteAlarm
+## Description: This function delets a specific alarm from the AMEMO alarm queue
+## Parameters:  none
+## Returns:     none
 ###########################################################################
 def DeleteAlarm():
     if(data.AlarmID!=-1): #there is an old alarm to be deleted
@@ -108,7 +124,7 @@ def DeleteAlarm():
                 event = alarm.get_event(data.AlarmID) #get data of to be deleted alarm
                 alarm.delete_event(data.AlarmID)
 
-                print "* Delete old Alarm:",  time.ctime(event.trigger)
+                print "* Delete old Alarm:", time.ctime(event.trigger)
             except:
                 pass
         else:
@@ -128,19 +144,19 @@ def DeleteAlarm():
 
 
 
-
-
 ###########################################################################
-## Gets called in the timer loop
-## Checks if the alarm should be set off
+## Function:    ProcessAlarm
+## Description: This function checks if the latest value of the blue sleep
+##				alarm curve is over the trigger level and sets off an alarm
+##				or the wake up music
+## Parameters:  none
+## Returns:     none
 ###########################################################################
 def ProcessAlarm():
     i=records.Index-data.Derivation
-#    if(i>1): peak=records.arrData[4][i-1] #check if last movement is over trigger level
     if(i>1): peak=records.arrData[6][i-1] #New: use blue graph for triggering
     else: peak=0
     now=Tuple2Seconds(time.localtime())
-#    if(peak>data.Trigger): #big Movement
     if(peak>(data.Trigger*data.Yscale_Sleep_Pattern*3/40)): #Trigger Alarm
        if(records.AlarmIsSet==True and data.AlarmIsActive==False): #alarm is set
             if(now>=records.AlarmTimeWindowStart_seconds and now<records.AlarmTimeWindowEnd_seconds): # we are in alarm time window
@@ -154,15 +170,14 @@ def ProcessAlarm():
                     if(records.Use_WakeUp_Song==True): #Delay alarm, so we can first play wake up song
                         print "* Alarm would be now:", records.AlarmTime_tuple
                         print "* But wake Up song is enabled, delay alarm for", records.WakeUp_Song_Duration/60, "minutes"
-                        records.AlarmTime_seconds=min(records.AlarmTime_seconds+records.WakeUp_Song_Duration+10, records.AlarmTimeWindowEnd_seconds) #add delay time, but max until alarm time window
+                        records.AlarmTime_seconds=min(records.AlarmTime_seconds+records.WakeUp_Song_Duration, records.AlarmTimeWindowEnd_seconds) #add delay time, but max until alarm time window
                         records.AlarmTime_tuple=Seconds2Tuple(records.AlarmTime_seconds)
                         data.WakeUp_SongIsActive=True
                         records.WakeUp_Song_Start_tuple=Seconds2Tuple(now)
                         print "* Delay alarm until:", records.AlarmTime_tuple
 
                         print "** Play wake up song"
-#                        PlaySong(records.WakeUp_Song_Volume, records.WakeUp_Song)
-                        PlaySong(0, records.WakeUp_Song) #startquiet, get louder over time
+                        PlaySong(0, records.WakeUp_Song) #start quiet, get louder over time
 
                     print "*", strftime("%x %X"), "ProcessAlarm => SetAlarm" #for log file
                     SetAlarm() #set alarm to go off now (or with wake up song delay)
@@ -183,20 +198,25 @@ def ProcessAlarm():
 #            PauseSong() #stop playing song, in case it was playing
             CloseMediaPlayer() #close media player
 
-
     if(data.WakeUp_SongIsActive==True): #when WakeUp music is active, increase volume over time
         if(records.WakeUp_Song_Volume>data.CurrentVolume):
             SetVolume(data.CurrentVolume+1)
             print "Increase volume to:", data.CurrentVolume
 
 
+
+
+
 ###########################################################################
-## Checks if it is time to start the ucid dream song
+## Function:    ProcessLucid_Dream
+## Description: This function sets off the lucid dream music if we are
+##				longer than required time in light or deep sleep				
+## Parameters:  none
+## Returns:     none
 ###########################################################################
 def ProcessLucid_Dream(): #Lucid dream option
     if(records.Use_Lucid_Dream_Song==True and data.Lucid_Dream_SongIsActive==False):
         GenerateStatisticData()
-#        print records.arrStatData[1][2], records.arrStatData[2][2]
         if(records.arrStatData[1][2] >= records.Lucid_Dream_Song_Delay or records.arrStatData[2][2] >= records.Lucid_Dream_Song_Delay):
             data.Lucid_Dream_SongIsActive=True
             records.Lucid_Dream_Song_Start_tuple=time.localtime() #now
