@@ -1,5 +1,11 @@
 # -*- coding: utf-8 -*-
 
+###########################################################################
+## File:		functions_file.py
+## Description: This file includes the functions to read,  write and modify
+##				the record files
+###########################################################################
+
 import sys
 import os
 import random
@@ -19,20 +25,25 @@ import records #record data
 from functions_general import *
 from functions_record import *
 
-#load language file
-import i18n
-#_ = i18n.language.gettext
+import i18n #load language file
 _ = i18n.language.ugettext
 
+
+
+
+
 ###########################################################################
-## Function to open or close the record file
+## Function:    CreateRecordFile
+## Description: This function creats the record data file
+## Parameters:  none
+## Returns:     none
 ###########################################################################
-def CreateRecordFile(interval):
+def CreateRecordFile():
     #if not on the N900, use another place for the record file
     if(data.DeviceIsN900==False): data.RecordFolder=data.developmentRecordFolder #folder on devel PC
     else: data.RecordFolder=data.defaultRecordFolder
 
-    print "RecordFolder:",  data.RecordFolder
+    print "RecordFolder:", data.RecordFolder
     if(not os.path.exists(data.RecordFolder)): #create record folder
         try:
             os.mkdir(data.RecordFolder)
@@ -41,7 +52,6 @@ def CreateRecordFile(interval):
 
     if(data.debug==True): PrintRecordData()
 
-
     #create file, write header
     d=strftime("%Y-%m-%d_%H-%M-%S", records.StartTime_tuple)
     data.RecordFilename="SleepAnalyser_"+d+".csv"
@@ -57,15 +67,15 @@ def CreateRecordFile(interval):
 
 
 
-
-
-
 ###########################################################################
-##
+## Function:    CreateHeader
+## Description: This function creats the header data for the record data file
+## Parameters:  none
+## Returns:     none
 ###########################################################################
 def CreateHeader():
-    if(records.SWversion<1.8): records.SWversion=1.8 #update file version as header gets saved in new version
-                                                                                    #This value should be updated every time a file structure change happens!
+    if(records.SWversion<1.8): records.SWversion=1.8 #Workaround for missing version variable, update file version as header gets saved in new version
+
     h=" , , , User: " + str(records.User.encode( "utf-8" ))+ \
         ", SW version: " + str(records.SWversion)+ \
         ", Sampling interval: " + str(records.Sampling_interval)+ \
@@ -73,8 +83,7 @@ def CreateHeader():
         ", Value smoothing: " + str(records.Value_smoothing) + \
         ", Trigger level: " + str(records.Trigger)
 
-    h=h+"\n"+"Start time: "+strftime(data.dateformat,  records.StartTime_tuple)
-
+    h=h+"\n"+"Start time: "+strftime(data.dateformat, records.StartTime_tuple)
 
     if(records.AlarmIsSet==True):
         if(records.AlarmTime_tuple!=-1):
@@ -130,34 +139,33 @@ def CreateHeader():
         h=h+"\n"+ "WakeUp song duration: Not set"
         h=h+"\n"+ "WakeUp song volume: Not set"
 
-
-    #for future usage
+    #reserved for future usage
     h=h+"\n"+"Spare"
     h=h+"\n"+"Spare"
     h=h+"\n"+"Spare"
     h=h+"\n"+"Spare"
     h=h+"\n"+"Spare"
 
+    h=h+"\n"+"Time, AccX, AccY, AccY:\n" #not really used, only here for understanding of file structure
 
-    h=h+"\n"+"Time, AccX, AccY, AccY:\n"
-
-#    print "Record header:\n"+h+"\n"
     if(data.debug==True): print "##############################\nHeader:\n"+h+"\n##############################"
     return h
 
 
 
-
+	
+	
 ###########################################################################
-##  Write data into file, so it can be used in other tools
+## Function:    WriteRecord
+## Description: This function writes the acceleration data into the record data file
+## Parameters:  none
+## Returns:     none
 ###########################################################################
 def WriteRecord():
-
     d=str(records.arrData[0][records.Index-1]) + ", " +  \
         str(records.arrData[1][records.Index-1]) + ", " +  \
         str(records.arrData[2][records.Index-1]) + ", " +  \
         str(records.arrData[3][records.Index-1]) + ", "
-#        str(records.arrData[5][records.Index-1]) ##event note, not used anymore
 
     data.RecordFile.write(d+"\n")
 #    if(data.debug==True): print "Write to file:",d
@@ -169,12 +177,17 @@ def WriteRecord():
 
 
 
+
+
 ###########################################################################
-##  Close record file
+## Function:    StopRecordFile
+## Description: This function closes the record data file after recording end 
+## Parameters:  none
+## Returns:     none
 ###########################################################################
 def StopRecordFile():
     if(records.AlarmIsSet==True):
-        records.LastIndex=max(records.Index,  Tuple2Index(records.AlarmTimeWindowEnd_tuple)+5) #the very last index to be shown (incl. AlarmTimeWindowEnd
+        records.LastIndex=max(records.Index, Tuple2Index(records.AlarmTimeWindowEnd_tuple)+5) #the very last index to be shown (incl. AlarmTimeWindowEnd
     else: records.LastIndex=records.Index
     data.RecordFile.close()
 
@@ -182,10 +195,14 @@ def StopRecordFile():
 
 
 ###########################################################################
-##  Load list of record files into array
+## Function:    LoadFileList
+## Description: This function creates a list of all record data files in the
+##				folder defined in defaultRecordFolder
+## Parameters:  none
+## Returns:     none
 ###########################################################################
 def LoadFileList():
-    print "Load list of all csv files in folder:",  data.RecordFolder
+    print "Load list of all csv files in folder:", data.RecordFolder
     output = os.popen("cd "+str(data.RecordFolder)+"; ls -C1 *.csv").read() # run ls and make the output look like a file I can read
     data.arrRecordFiles=output.split("\n")
     data.arrRecordFiles.pop()
@@ -196,22 +213,23 @@ def LoadFileList():
         for i in range(len(data.arrRecordFiles)):
             if(data.RecordFilename==data.arrRecordFiles[i]): data.arrRecordFilesIndex=i
 
-    if(data.debug==True): print "LoadFileList,  Index:",  data.arrRecordFilesIndex
-
-
+    if(data.debug==True): print "LoadFileList, Index:", data.arrRecordFilesIndex
 
 
 
 
 
 ###########################################################################
-##  Load record file  to read and visualise it
+## Function:    LoadRecord
+## Description: This function loads the complete record data file into the record array
+## Parameters:  none
+## Returns:     none
 ###########################################################################
 def LoadRecord():
     InitRecord() #clear all old data
 
-    data.RecordFolder=string.replace(data.RecordFolder, "~",  data.homedir) #workaround
-    print "Open recordfile:",  data.RecordFolder+data.RecordFilename,  "to load data..."
+    data.RecordFolder=string.replace(data.RecordFolder, "~", data.homedir) #workaround
+    print "Open recordfile:", data.RecordFolder+data.RecordFilename, "to load data..."
     if(not os.path.exists(data.RecordFolder)): #create record folder (dirty workaround for if folder is not existing
         os.mkdir(data.RecordFolder)
         data.LastRecord=""
@@ -224,59 +242,59 @@ def LoadRecord():
        #process header line 1
         tmp=file.readline()
         header=string.split(tmp, ", ")
-        records.SWversion=float(string.replace(header[4], "SW version:",  ""))
+        records.SWversion=float(string.replace(header[4], "SW version:", ""))
         print "File has software version", records.SWversion
         if(records.SWversion<1.6): #workaround for old files
             print "Record is older than SW version 1.6, use old protocol"
-            records.User=string.replace(header[3].decode("utf-8") , "User:",  "")
-            Startdate_date=string.replace(header[5], "Date:",  "")
-            x=string.replace(header[6], "Sampling interval:",  "")
-            records.Sampling_interval=int(string.replace(x, " ms",  ""))
-            records.Sample_smoothing=int(string.replace(header[7], "sampling smoothing:",  ""))
-            records.Value_smoothing=int(string.replace(header[8], "value_smoothing:",  ""))
+            records.User=string.replace(header[3].decode("utf-8") , "User:", "")
+            Startdate_date=string.replace(header[5], "Date:", "")
+            x=string.replace(header[6], "Sampling interval:", "")
+            records.Sampling_interval=int(string.replace(x, " ms", ""))
+            records.Sample_smoothing=int(string.replace(header[7], "sampling smoothing:", ""))
+            records.Value_smoothing=int(string.replace(header[8], "value_smoothing:", ""))
             records.Trigger=30
         else:
-            records.User=string.replace(header[3].decode("utf-8") , "User:",  "")
-            records.Sampling_interval=int(string.replace(header[5], "Sampling interval:",  ""))
-            records.Sample_smoothing=int(string.replace(header[6], "Sample smoothing:",  ""))
-            records.Value_smoothing=int(string.replace(header[7], "Value smoothing:",  ""))
-            records.Trigger=int(string.replace(header[8], "Trigger level:",  ""))
+            records.User=string.replace(header[3].decode("utf-8") , "User:", "")
+            records.Sampling_interval=int(string.replace(header[5], "Sampling interval:", ""))
+            records.Sample_smoothing=int(string.replace(header[6], "Sample smoothing:", ""))
+            records.Value_smoothing=int(string.replace(header[7], "Value smoothing:", ""))
+            records.Trigger=int(string.replace(header[8], "Trigger level:", ""))
 
         if(records.SWversion<1.2): #workaround for old files
             records.Notes=""
         elif(records.SWversion<1.6): #workaround for old files
             #process header line 2
             tmp=file.readline()
-            records.Note=string.replace(tmp[:-1].decode("utf-8"), "Note: ",  "")
+            records.Note=string.replace(tmp[:-1].decode("utf-8"), "Note: ", "")
         else:
            #process header line 2
             tmp=file.readline()
-            tmp=string.replace(tmp[:-1], "Start time: ",  "")
-            records.StartTime_tuple=time.strptime(tmp,  data.dateformat)
+            tmp=string.replace(tmp[:-1], "Start time: ", "")
+            records.StartTime_tuple=time.strptime(tmp, data.dateformat)
             records.StartTime_seconds=Tuple2Seconds( records.StartTime_tuple)
 
            #process header line 3
             tmp=file.readline()
             if(tmp[:-1]!="No alarm set"):
                 if(data.debug==True): print "An alarm is set"
-                tmp=string.replace(tmp[:-1], "Alarm: ",  "")
-                records.AlarmTime_tuple=time.strptime(tmp,  data.dateformat)
+                tmp=string.replace(tmp[:-1], "Alarm: ", "")
+                records.AlarmTime_tuple=time.strptime(tmp, data.dateformat)
                 records.AlarmTime_seconds=Tuple2Seconds( records.AlarmTime_tuple)
             else:
                 if(data.debug==True): print "No alarm is set"
 
            #process header line 4
             tmp=file.readline()
-            tmp=string.replace(tmp[:-1], "Alarm Time Window Start: ",  "")
+            tmp=string.replace(tmp[:-1], "Alarm Time Window Start: ", "")
             if(tmp!="Not set"):
-                records.AlarmTimeWindowStart_tuple=time.strptime(tmp,  data.dateformat)
+                records.AlarmTimeWindowStart_tuple=time.strptime(tmp, data.dateformat)
                 records.AlarmTimeWindowStart_seconds=Tuple2Seconds(records.AlarmTimeWindowStart_tuple)
 
            #process header line 5
             tmp=file.readline()
-            tmp=string.replace(tmp[:-1], "Alarm Time Window End: ",  "")
+            tmp=string.replace(tmp[:-1], "Alarm Time Window End: ", "")
             if(tmp!="Not set"):
-                records.AlarmTimeWindowEnd_tuple=time.strptime(tmp,  data.dateformat)
+                records.AlarmTimeWindowEnd_tuple=time.strptime(tmp, data.dateformat)
                 records.AlarmTimeWindowEnd_seconds=Tuple2Seconds( records.AlarmTimeWindowEnd_tuple)
                 records.AlarmTimeWindow_minutes=int((records.AlarmTimeWindowEnd_seconds-records.AlarmTimeWindowStart_seconds)/60)
                 if(records.AlarmTimeWindowStart_tuple!=-1): records.AlarmIsSet=True
@@ -284,23 +302,22 @@ def LoadRecord():
             if(records.SWversion>=2.1):
                 #process header line 6
                 tmp=file.readline()
-                tmp=string.replace(tmp[:-1], "Use alternative Alarm: ",  "")
+                tmp=string.replace(tmp[:-1], "Use alternative Alarm: ", "")
                 if(tmp=="False"): records.UseAlternativeAlarm=False
                 else: records.UseAlternativeAlarm=True
 
                 #process header line 7
                 tmp=file.readline()
-                records.AlternativeAlarm=string.replace(tmp[:-1], "Alternative Alarm: ",  "")
+                records.AlternativeAlarm=string.replace(tmp[:-1], "Alternative Alarm: ", "")
 
            #process header line 8
             tmp=file.readline()
-            records.Note=string.replace(tmp[:-1].decode("utf-8"), "Note: ",  "")
-
+            records.Note=string.replace(tmp[:-1].decode("utf-8"), "Note: ", "")
 
             if(records.SWversion>=2.0):
                 #process header line 9..12
                 tmp=file.readline()
-                tmp=string.replace(tmp[:-1], "Lucid dream song start: ",  "")
+                tmp=string.replace(tmp[:-1], "Lucid dream song start: ", "")
                 if(tmp=="Not set"):
                     records.Use_Lucid_Dream_Song=False
                     file.readline() #drop line
@@ -310,22 +327,21 @@ def LoadRecord():
                 else: #used lucid dream option
                     records.Use_Lucid_Dream_Song=True
                     if(tmp!="never"):
-                        records.Lucid_Dream_Song_Start_tuple=time.strptime(tmp,  data.dateformat)
+                        records.Lucid_Dream_Song_Start_tuple=time.strptime(tmp, data.dateformat)
                     else:
                         records.Lucid_Dream_Song_Start_tuple=-1
                     tmp=file.readline()
-                    records.Lucid_Dream_Song=string.replace(tmp[:-1], "Lucid dream song: ",  "")
+                    records.Lucid_Dream_Song=string.replace(tmp[:-1], "Lucid dream song: ", "")
                     tmp=file.readline()
-                    records.Lucid_Dream_Song_Delay=int(string.replace(tmp[:-1], "Lucid dream song delay: ",  ""))
+                    records.Lucid_Dream_Song_Delay=int(string.replace(tmp[:-1], "Lucid dream song delay: ", ""))
                     tmp=file.readline()
-                    records.Lucid_Dream_Song_Duration=int(string.replace(tmp[:-1], "Lucid dream song duration: ",  ""))
+                    records.Lucid_Dream_Song_Duration=int(string.replace(tmp[:-1], "Lucid dream song duration: ", ""))
                     tmp=file.readline()
-                    records.Lucid_Dream_Song_Volume=int(string.replace(tmp[:-1], "Lucid dream song volume: ",  ""))
-
+                    records.Lucid_Dream_Song_Volume=int(string.replace(tmp[:-1], "Lucid dream song volume: ", ""))
 
                 #process header line 13..16
                 tmp=file.readline()
-                tmp=string.replace(tmp[:-1], "WakeUp song start: ",  "")
+                tmp=string.replace(tmp[:-1], "WakeUp song start: ", "")
                 if(tmp=="Not set"):
                     records.Use_WakeUp_Song=False
                     file.readline() #drop line
@@ -334,17 +350,15 @@ def LoadRecord():
                 else: #used lucid dream option
                     records.Use_WakeUp_Song=True
                     if(tmp!="never"):
-                        records.WakeUp_Song_Start_tuple=time.strptime(tmp,  data.dateformat)
+                        records.WakeUp_Song_Start_tuple=time.strptime(tmp, data.dateformat)
                     else:
                         records.WakeUp_Song_Start_tuple=-1
                     tmp=file.readline()
-                    records.WakeUp_Song=string.replace(tmp[:-1], "WakeUp song: ",  "")
+                    records.WakeUp_Song=string.replace(tmp[:-1], "WakeUp song: ", "")
                     tmp=file.readline()
-                    records.WakeUp_Song_Duration=int(string.replace(tmp[:-1], "WakeUp song duration: ",  ""))
+                    records.WakeUp_Song_Duration=int(string.replace(tmp[:-1], "WakeUp song duration: ", ""))
                     tmp=file.readline()
-                    records.WakeUp_Song_Volume=int(string.replace(tmp[:-1], "WakeUp song volume: ",  ""))
-
-
+                    records.WakeUp_Song_Volume=int(string.replace(tmp[:-1], "WakeUp song volume: ", ""))
 
             if(records.SWversion>=2.0):
                 #spare lines 17..21
@@ -354,11 +368,9 @@ def LoadRecord():
                 tmp=file.readline() #drop line
                 tmp=file.readline() #drop line
 
-
           #process header line 22
             tmp=file.readline()  #not used, column header
 
-
         print "Record header successful read"
     except:
         print "Record header data corrupt"
@@ -368,40 +380,24 @@ def LoadRecord():
         file.close()
         return 8
 
-
-    PrintRecordData()
-
-
+	#header loaded, now load data
     records.Index=0
     try: #get data
         for line in file:
-    #            print line
-            d=string.split(line[:-1],  ", ")
-    #                print len(d)
+            d=string.split(line[:-1], ", ")
             records.arrData[0][records.Index]=d[0] #time
             records.arrData[1][records.Index]=int(d[1]) #X
             records.arrData[2][records.Index]=int(d[2]) #Y
             if(records.SWversion<1.8): #workaround for old files (versions <1.8 had only X and Y axis stored)
                 records.arrData[3][records.Index]=0 #Z
-#                try:
-#                    records.arrData[5][records.Index]=d[3] #Event
-#                except:
-#                    pass
             else:
                 records.arrData[3][records.Index]=int(d[3]) #Z
-#                try:
-#                    records.arrData[5][records.Index]=d[4] #Event
-#                except:
-#                    pass
 
             records.Index=records.Index+1
             if(records.Index==records.MaxArrayDataLen-1):
-                print "Stopped, array is full, file is to big. Loaded ",  records.Index,  "lines"
-    #                records.status="Data Array is full (max "+str(records.MaxArrayDataLen)+ " entries)"
+                print "Stopped, array is full, file is to big. Loaded ", records.Index, "lines"
                 records.status="Data array is full"
                 records.statusID="ARRAY_FULL"
-    #                file.close()
-    #                return 7 #File to long
                 break
     except:
         print "File is corrupted"
@@ -418,20 +414,19 @@ def LoadRecord():
         records.statusID="NO_DATA"
         return 4
 
-
     if(records.SWversion<1.6): #workaround for old files
-        if(records.Index>0): records.StartTime_tuple=time.strptime(Startdate_date+" "+str(records.arrData[0][0]),  " %d-%m-%Y %H:%M:%S") #no data anyway
-        else: records.StartTime_tuple=time.strptime(Startdate_date+" 00:00:00",  " %d-%m-%Y %H:%M:%S") #no data anyway
+        if(records.Index>0): records.StartTime_tuple=time.strptime(Startdate_date+" "+str(records.arrData[0][0]), " %d-%m-%Y %H:%M:%S") #no data anyway
+        else: records.StartTime_tuple=time.strptime(Startdate_date+" 00:00:00", " %d-%m-%Y %H:%M:%S") #no data anyway
         records.StartTime_seconds=Tuple2Seconds(records.StartTime_tuple)
 
     #calculate end time
     records.EndTime_seconds=Tuple2Seconds(records.StartTime_tuple)+records.Index*records.Sampling_interval*records.Value_smoothing/1000
     records.EndTime_tuple=Seconds2Tuple(records.EndTime_seconds)
 
-    print "Loaded successful",  records.Index, "lines"
+    print "Loaded successful", records.Index, "lines"
     if(records.AlarmIsSet==True):
-        records.LastIndex=max(records.Index,  Tuple2Index(records.AlarmTimeWindowEnd_tuple)+5) #the very last index to be shown (incl. AlarmTimeWindowEnd
-        if(data.debug==True): print "But will show up to index",  records.LastIndex,  "as the AlarmTimeWindow ends there"
+        records.LastIndex=max(records.Index, Tuple2Index(records.AlarmTimeWindowEnd_tuple)+5) #the very last index to be shown (incl. AlarmTimeWindowEnd
+        if(data.debug==True): print "But will show up to index", records.LastIndex, "as the AlarmTimeWindow ends there"
     else: records.LastIndex=records.Index
 
     records.status=_("Data successful loaded")
@@ -445,30 +440,24 @@ def LoadRecord():
 
 
 
-
-#def GetLine(replace=""):
-#    tmp=file.readline()
-#    tmp=string.replace(tmp[:-1], replace,  "")
-#    return tmp
-
-
-
 ###########################################################################
-##
+## Function:    UpdateFileHeader
+## Description: This function updates the header data
+## Parameters:  none
+## Returns:     none
 ###########################################################################
 def UpdateFileHeader():
-#    print "Reopen record file and update note:",  records.Note
     file = open(data.RecordFolder+data.RecordFilename, 'w')
-    print "Update header in RecordFile",  data.RecordFilename
+    print "Update header in RecordFile", data.RecordFilename
 
     h=CreateHeader()
     file.write(h)
     i=0
-    for i in range(0,  records.Index):
+    for i in range(0, records.Index):
         d=str(records.arrData[0][i]) + ", " + str(records.arrData[1][i]) + ", " +  str(records.arrData[2][i]) + \
             ", " +  str(records.arrData[3][i])
 #        d=str(records.arrData[0][i]) + ", " + str(records.arrData[1][i]) + ", " +  str(records.arrData[2][i]) + \
 #            ", " +  str(records.arrData[3][i]) + ", " +  str(records.arrData[5][i])
         file.write(d+"\n")
     file.close()
-    if(data.debug==True): print "Wrote",  i +1,  "records into file"
+    if(data.debug==True): print "Wrote", i +1, "records into file"
