@@ -1,5 +1,10 @@
 # -*- coding: utf-8 -*-
 
+###########################################################################
+## File:		functions_general.py
+## Description: This file includes various functions
+###########################################################################
+
 from PyQt4.QtCore import *
 from PyQt4.QtGui import *
 from PyQt4 import QtCore, QtGui
@@ -24,18 +29,25 @@ import filter_data #filter
 import records #record data
 
 
-#load language file
-import i18n
-#_ = i18n.language.gettext
+
+import i18n #load language file
 _ = i18n.language.ugettext
 
+
+
+
 ###########################################################################
-## Load the configuration from the config file
+## Function:    LoadConfig
+## Description: This function loads the data from the config file
+##				If the parameter is missing in the config file, it uses
+##				the default value from file data.py
+## Parameters:  none
+## Returns:     none
 ###########################################################################
 def LoadConfig():
     #get configuration
     global config
-    if(data.debug==True): print "Configuration file:",  data.configFolder+data.ConfigFile
+    if(data.debug==True): print "Configuration file:", data.configFolder+data.ConfigFile
     config = ConfigParser.SafeConfigParser()
     try:
         config.read(data.configFolder+data.ConfigFile)
@@ -251,11 +263,6 @@ def LoadConfig():
         config.set('main', 'Deep_Sleep_Level', str(data.Deep_Sleep_Level))
 
 
-    print "data.Light_Sleep_Level:", data.Light_Sleep_Level
-    print "data.Deep_Sleep_Level:", data.Deep_Sleep_Level
-
-
-
 ## Add forced configuration changes here
     try:
         configFileVersion = config.getint('main', 'configFileVersion')
@@ -276,19 +283,18 @@ def LoadConfig():
         pass
 
     print "Configuration successful loaded from "+data.ConfigFile
-    PrintConfig()
+#    PrintConfig() ##debug only
     return config
 
 
 
 
 
-
-
-
-
 ###########################################################################
-## Write the configuration into the config file
+## Function:    WriteConfig
+## Description: This function loads the config into the config file
+## Parameters:  none
+## Returns:     none
 ###########################################################################
 def WriteConfig():
     global config
@@ -298,7 +304,7 @@ def WriteConfig():
     f=data.configFolder+data.ConfigFile
     if(data.debug==True): print "Save configuration ("+f+")"
     if (not os.path.exists(data.configFolder)):
-        print "Create configuration folder: ",  data.configFolder
+        print "Create configuration folder: ", data.configFolder
         os.mkdir(data.configFolder)
     try:
         data.configfile = open(f, 'w')
@@ -311,6 +317,13 @@ def WriteConfig():
 
 
 
+###########################################################################
+## Function:    PrintConfig
+## Description: This function prints out the current configuration
+##				It is for debugging only
+## Parameters:  none
+## Returns:     none
+###########################################################################
 def PrintConfig():
     print "###################### CONFIG DATA #######################"
     a=config.items("main")
@@ -319,17 +332,28 @@ def PrintConfig():
     print "##########################################################"
 
 
+	
+	
 ###########################################################################
-##
+## Function:    Seconds2Tuple
+## Description: This function converts the integer value of seconds since 1970
+##				into a time tuple
+## Parameters:  seconds since 1970
+## Returns:     time tuple
 ###########################################################################
 def Seconds2Tuple(secs):
     tuple=time.localtime(secs)
     return tuple
 
 
+	
 
 ###########################################################################
-##
+## Function:    Tuple2Seconds
+## Description: This function converts the time tupple into an integer
+##				of seconds since 1970
+## Parameters:  time tuple
+## Returns:     seconds since 1970
 ###########################################################################
 def Tuple2Seconds(Tuple):
     secs=int(time.mktime(Tuple))
@@ -337,26 +361,33 @@ def Tuple2Seconds(Tuple):
 
 
 
+	
 ###########################################################################
-##
+## Function:    Tuple2Index
+## Description: This function calculates the index in the recod array from
+##				the parameter Tuple, relative to the record start time
+## Parameters:  time Tuple
+## Returns:     record array index
 ###########################################################################
 def Tuple2Index(Tuple):
     t0=records.StartTime_seconds
     t1=Tuple2Seconds(Tuple)
     tdiff=t1-t0
-#    print records.StartTime_tuple,  Tuple
-#    print "Tuple2Index:",  t0,  t1,  tdiff,  float(1000)/(records.Sampling_interval*records.Value_smoothing)
-#    return Seconds2Index(tdiff)
     return int((tdiff-10)*1000/(records.Sampling_interval*records.Value_smoothing))+3
 
 
 
+	
+	
 ###########################################################################
-##
+## Function:    Index2Tuple
+## Description: This function calculates the time tuple out of the
+##				parameter Index relative to the record start time
+## Parameters:  Index from record array
+## Returns:     time tuple
 ###########################################################################
 def Index2Tuple(Index):
     tdiff=int(Index*records.Sampling_interval*records.Value_smoothing/1000-3)+10
-#    tdiff=Index2Seconds(Index)
     t=records.StartTime_seconds+tdiff
     return Seconds2Tuple(t)
 
@@ -367,6 +398,13 @@ def Index2Tuple(Index):
 
 
 
+###########################################################################
+## Function:    SwitchModes
+## Description: This function switches to offline mode and silence profile
+##				if requested and restores the previos state after the recording
+## Parameters:  start: True (recording start), False (recording end)
+## Returns:     none
+###########################################################################
 def SwitchModes(start):
     if(data.DeviceIsN900==True): #We are on a N900
         if(data.QuickMode==False):  #only do in normal recording mode
@@ -392,6 +430,12 @@ def SwitchModes(start):
 
 
 
+###########################################################################
+## Function:    set_profile
+## Description: This function switches to the requested online/offline mode
+## Parameters:  online: True (switch to online mode), False (switch to offline mode)
+## Returns:     none
+###########################################################################
 def set_profile(online):
     if(online==True):
         try:
@@ -407,7 +451,7 @@ def set_profile(online):
             ret=os.popen2(cmd) #get current mode
             p=ret[1].readline() #not used
             p=ret[1].readline()
-            tmp=string.split(p,  "\"")
+            tmp=string.split(p, "\"")
             data.PreviousMode=tmp[1]
             if(data.PreviousMode=="normal"): #was normal, change to offline
                 print "Change to offline mode"
@@ -421,6 +465,13 @@ def set_profile(online):
 
 
 
+
+###########################################################################
+## Function:    set_silent
+## Description: This function switches to the requested profile
+## Parameters:  silent: True (switch to silent profile), False (switch to normal profile)
+## Returns:     none
+###########################################################################
 def set_silent(silent):
     if(silent==True):
         try:
@@ -428,7 +479,7 @@ def set_silent(silent):
             ret=os.popen2(cmd) #get current profile
             p=ret[1].readline() #not used
             p=ret[1].readline()
-            tmp=string.split(p,  "\"")
+            tmp=string.split(p, "\"")
             data.PreviousProfile=tmp[1]
             if(data.PreviousProfile=="general"): #was general profile, change to silent profile
                 cmd="dbus-send --type=method_call --dest=com.nokia.profiled /com/nokia/profiled com.nokia.profiled.set_profile string:\"silent\" | echo \"\""
@@ -451,16 +502,27 @@ def set_silent(silent):
 
 
 
-
-
-
+###########################################################################
+## Function:    SetVolume
+## Description: This function sets the requested volume
+## Parameters:  volume percent: 0..100
+## Returns:     none
+###########################################################################
 def SetVolume(percent):
     cmd="dbus-send --type=method_call --dest=com.nokia.mafw.renderer.Mafw-Gst-Renderer-Plugin.gstrenderer /com/nokia/mafw/renderer/gstrenderer com.nokia.mafw.extension.set_extension_property string:volume variant:uint32:"+str(percent)
     os.popen(cmd)
     data.CurrentVolume=percent
 
 
+	
 
+
+###########################################################################
+## Function:    GetVolume
+## Description: This function returns the requested volume
+## Parameters:  none
+## Returns:     volume percent: 0..100
+###########################################################################
 def GetVolume():
     if(data.DeviceIsN900==True): #we are on a N900
         bus = dbus.SessionBus()
@@ -473,12 +535,27 @@ def GetVolume():
 
 
 
+		
+		
+###########################################################################
+## Function:    Notify
+## Description: Shows a notification message
+## Parameters:  text to be shown
+## Returns:     none
+###########################################################################
 def Notify(notify_txt):
     notify_cmd="dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:\""+notify_txt+"\""
     os.popen(notify_cmd.encode( "utf-8" ))
 
 
 
+	
+###########################################################################
+## Function:    PlaySong
+## Description: Sets the requested volume and opens the media player with the requested song
+## Parameters:  volume percent (0..100), path to song file
+## Returns:     none
+###########################################################################
 def PlaySong(volume, filename):
     print strftime("%x %X"), "Play", filename, "with volume", volume
     cmd="dbus-send --print-reply --dest=com.nokia.mediaplayer /com/nokia/mediaplayer com.nokia.mediaplayer.mime_open string:\"file:///"+str(filename)+"\""
@@ -489,6 +566,13 @@ def PlaySong(volume, filename):
 
 
 
+	
+###########################################################################
+## Function:    PauseSong
+## Description: This function switches the media player to pause
+## Parameters:  none
+## Returns:     volume percent: 0..100
+###########################################################################
 def PauseSong():
     print strftime("%x %X"), "Pause song (if active)"
     cmd="dbus-send --dest=com.nokia.mafw.renderer.Mafw-Gst-Renderer-Plugin.gstrenderer /com/nokia/mafw/renderer/gstrenderer com.nokia.mafw.renderer.pause"
@@ -497,6 +581,14 @@ def PauseSong():
 
 
 
+	
+	
+###########################################################################
+## Function:    GetSongLength
+## Description: This function returns the duration of a song
+## Parameters:  path to song file
+## Returns:     song duration in seconds
+###########################################################################
 def GetSongLength(filename):
     print "get song length for file:", filename
     output = os.popen("ffmpeg -i \""+str(filename)+"\" 2>&1 | grep Duration").read() # run ffmpeg and make the output look like a file I can read
@@ -507,6 +599,14 @@ def GetSongLength(filename):
 
 
 
+	
+	
+###########################################################################
+## Function:    CloseMediaPlayer
+## Description: This function closes the media player
+## Parameters:  none
+## Returns:     none
+###########################################################################
 def CloseMediaPlayer():
     print strftime("%x %X"), "killall mediaplayer"
     cmd="killall mediaplayer"
@@ -517,16 +617,20 @@ def CloseMediaPlayer():
 
 
 
+###########################################################################
+## Function:    CloseMediaPlayer
+## Description: This function can measure the time needed for a certain code block
+##				It is only used for debugging
+## Parameters:  text to be printer, reset time: True/False
+## Returns:     none
 ############################################################################
-## Function to measure used time in a function
-############################################################################
-#def Show_passed_time(text="",  reset=0):
+#def Show_passed_time(text="", reset=False):
 #    if(data.debug==False): return
 #    now=time.time()
-#    if(reset==1): data.passed_time=now
+#    if(reset==True): data.passed_time=now
 #
 #    t=1000*(now-data.passed_time)
 #    t2=1000*(now-data.passed_time2)
-#    print "### ",  str(int(t)), "ms, (",  str(int(t2)), "ms delta): ", text
+#    print "### ", str(int(t)), "ms, (", str(int(t2)), "ms delta): ", text
 #
 #    data.passed_time2 = time.time()
